OiRA

# OiRA@Daimler

OiRA - Évaluation interactive des risques en ligne

## Mon évaluation des risques

Filters

Close

Hide archived risk assessments

Sélectionner une session antérieure à compléter ou réviser ou Commencer une nouvelle session.

- #### Private Security, Grafton Street

  Commencé le 5 May 2019

  More

- #### Commercial guarding, Leicester

  Commencé le 6 March 2020

  More

## Outils Oira disponibles

EU Cleaning EU Hairdressing EU Live Performance - Productions Leather and Tanning Maritime Transport Private Security

Back

## index-logged-in.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More